SET OPTION PUBLIC.preserve_source_format = 'OFF'
go


-------------------------------------------------
--   Create tables
-------------------------------------------------

CREATE TABLE "ADMIN"."LkpImiona" (
    "imie"                           char(32) NOT NULL
   ,CONSTRAINT "LKPIMIONA_PK" PRIMARY KEY ("imie" ASC) 
) IN "LOOKUP"
go

GRANT INSERT ON "ADMIN"."LkpImiona" TO "CONTROLLER" 
go

GRANT SELECT ON "ADMIN"."LkpImiona" TO "PUBLIC" 
go

CREATE TABLE "ADMIN"."LkpMiasta" (
    "id"                             integer NOT NULL DEFAULT autoincrement
   ,"nazwa"                          char(48) NOT NULL
   ,CONSTRAINT "LKPMIASTA_PK" PRIMARY KEY ("id" ASC) 
) IN "LOOKUP"
go

ALTER TABLE "ADMIN"."LkpMiasta"
    ADD CONSTRAINT "LKPMIASTA_AK" UNIQUE ( "nazwa" )
go

GRANT INSERT ON "ADMIN"."LkpMiasta" TO "CONTROLLER" 
go

GRANT SELECT ON "ADMIN"."LkpMiasta" TO "PUBLIC" 
go

CREATE TABLE "ADMIN"."LkpMiastoKod" (
    "miasto"                         integer NOT NULL
   ,"kod"                            integer NOT NULL
   ,"urzpocz"                        char(1) NOT NULL DEFAULT 'N'
) IN "LOOKUP"
go

GRANT SELECT ON "ADMIN"."LkpMiastoKod" TO "PUBLIC" 
go

CREATE TABLE "ADMIN"."LkpNBP" (
    "nrOddz"                         char(8) NOT NULL
   ,"nrCentr"                        char(8) NOT NULL
   ,"nazwaOddz"                      char(20) NOT NULL
   ,"miasto"                         char(48) NOT NULL
   ,CONSTRAINT "LKPNBP_PK" PRIMARY KEY ("nrOddz" ASC) 
) IN "LOOKUP"
go

GRANT INSERT ON "ADMIN"."LkpNBP" TO "CONTROLLER" 
go

GRANT SELECT ON "ADMIN"."LkpNBP" TO "PUBLIC" 
go

CREATE TABLE "ADMIN"."LkpPoczta" (
    "id"                             integer NOT NULL DEFAULT autoincrement
   ,"kod"                            char(5) NOT NULL
   ,CONSTRAINT "LKPPOCZTA_PK" PRIMARY KEY ("id" ASC) 
) IN "LOOKUP"
go

ALTER TABLE "ADMIN"."LkpPoczta"
    ADD CONSTRAINT "LKPPOCZTA_AK" UNIQUE ( "kod" )
go

GRANT INSERT ON "ADMIN"."LkpPoczta" TO "CONTROLLER" 
go

GRANT SELECT ON "ADMIN"."LkpPoczta" TO "PUBLIC" 
go

commit work
go


-------------------------------------------------
--   Reload data
-------------------------------------------------

INSERT INTO "ADMIN".Lookup VALUES('ADMIN', 'LkpImiona');
INSERT INTO "ADMIN".Lookup VALUES('ADMIN', 'LkpMiasta');
INSERT INTO "ADMIN".Lookup VALUES('ADMIN', 'LkpMiastoKod');
INSERT INTO "ADMIN".Lookup VALUES('ADMIN', 'LkpNBP');
INSERT INTO "ADMIN".Lookup VALUES('ADMIN', 'LkpPoczta');

commit work
go

LOAD TABLE "ADMIN"."LkpImiona"
	FROM 'LkpImiona.dat'
	FORMAT 'ASCII'
	ORDER OFF
	QUOTES ON ESCAPES ON STRIP OFF
	CHECK CONSTRAINTS OFF COMPUTES OFF
	DELIMITED BY ','
go

LOAD TABLE "ADMIN"."LkpMiasta"
	FROM 'LkpMiasta.dat'
	FORMAT 'ASCII'
	ORDER OFF
	QUOTES ON ESCAPES ON STRIP OFF
	CHECK CONSTRAINTS OFF COMPUTES OFF
	DELIMITED BY ','
go

LOAD TABLE "ADMIN"."LkpMiastoKod"
	FROM 'LkpMiastoKod.dat'
	FORMAT 'ASCII'
	ORDER OFF
	QUOTES ON ESCAPES ON STRIP OFF
	CHECK CONSTRAINTS OFF COMPUTES OFF
	DELIMITED BY ','
go

LOAD TABLE "ADMIN"."LkpNBP"
	FROM 'LkpNBP.dat'
	FORMAT 'ASCII'
	ORDER OFF
	QUOTES ON ESCAPES ON STRIP OFF
	CHECK CONSTRAINTS OFF COMPUTES OFF
	DELIMITED BY ','
go

LOAD TABLE "ADMIN"."LkpPoczta"
	FROM 'LkpPoczta.dat'
	FORMAT 'ASCII'
	ORDER OFF
	QUOTES ON ESCAPES ON STRIP OFF
	CHECK CONSTRAINTS OFF COMPUTES OFF
	DELIMITED BY ','
go

commit work
go


-------------------------------------------------
--   Create foreign keys
-------------------------------------------------

ALTER TABLE "ADMIN"."LkpMiastoKod"
    ADD NOT NULL FOREIGN KEY "LKPMIASTOKOD_LKPMIASTA_FK" ("miasto" ASC)
    REFERENCES "ADMIN"."LkpMiasta" ("id")
    ON DELETE CASCADE 
go

ALTER TABLE "ADMIN"."LkpMiastoKod"
    ADD NOT NULL FOREIGN KEY "LKPMIASTOKOD_LKPPOCZTA_FK" ("kod" ASC)
    REFERENCES "ADMIN"."LkpPoczta" ("id")
    ON DELETE CASCADE 
go

commit work
go


-------------------------------------------------
--   Create views
-------------------------------------------------

create view "ADMIN"."Miasta"( "kod","nazwa" ) 
  as select "P"."kod","M"."nazwa" from "ADMIN"."LkpPoczta" as "P","ADMIN"."LkpMiasta" as "M","ADMIN"."LkpMiastoKod" as "MK"
    where "P"."id" = "MK"."kod" and "M"."id" = "MK"."miasto" and "MK"."urzpocz" = 'T'
go

GRANT SELECT ON "ADMIN"."Miasta" TO "PUBLIC" 
go

create view "ADMIN"."Wsie"( "kod","nazwa" ) 
  as select "P"."kod","M"."nazwa" from "ADMIN"."LkpPoczta" as "P","ADMIN"."LkpMiasta" as "M","ADMIN"."LkpMiastoKod" as "MK"
    where "P"."id" = "MK"."kod" and "M"."id" = "MK"."miasto" and "MK"."urzpocz" = 'N'
go

GRANT SELECT ON "ADMIN"."Wsie" TO "PUBLIC" 
go

call dbo.sa_recompile_views(1)
go


-------------------------------------------------
--   Create options
-------------------------------------------------

SET OPTION PUBLIC.preserve_source_format =
go
